@@ -1,6 +1,5 @@
 from django.db import models
 from .managers import BulkManager,chunks
-import re
 
 # Create your models here.
 from .helper import fetch_celex_resource
@@ -58,7 +57,7 @@ class SpellingManager(BulkManager):
 class SyntacticCategory(models.Model):
     label = models.CharField(max_length=50)
     description = models.CharField(max_length=100,blank=True,null=True)
-    categoryType = models.CharField(max_length=100,blank=True,null=True)
+    category_type = models.CharField(max_length=100,blank=True,null=True)
 
     def __unicode__(self):
         return self.label
