@@ -10,6 +10,8 @@ from django.conf import settings
 from .models import *
 from .managers import BulkManager,chunks
 
+from .helper import fetch_media_resource
+
 logger = get_task_logger(__name__)
 
 def chunk_dict(d, n):
@@ -231,3 +233,56 @@ def loadTransWF(wfs):
 #                trans.extend([x[1] for x in additional])
 #            lemmas[l[0]]['Transcriptions'] = set(trans)
 #    return lemmas
+
+@task()
+def doStringSelect(form):
+    qs = WordForm.objects.all()
+    qs = qs.filter(lemma__category__in = form['categories']).prefetch_related()
+    if form['exclude_punctuation']:
+        qs = qs.exclude(orthographies__spelling__contains="'")
+        qs = qs.exclude(orthographies__spelling__contains=".")
+        qs = qs.exclude(orthographies__spelling__contains=",")
+        qs = qs.exclude(orthographies__spelling__contains='"')
+    if form['exclude_titlecase']:
+        qs = qs.exclude(orthographies__spelling__regex="^[A-Z]")
+    qs = qs.filter(transcriptions__cvskel = form['cvskel'])
+    with open(os.path.join(fetch_media_resource("Results"),"Celex","ConCon.txt"),'w') as f:
+        f.write("\t".join(["orth_one","orth_two","trans_one",'trans_two',
+                            "cat_one","cat_two","freq_one","freq_two",
+                            "lemma_one","lemma_two",
+                            "lemma_freq_one","lemma_freq_two",
+                            "phon_distance","in_context_entropy",
+                            ]))
+        f.write("\n")
+        for i in range(len(qs)):
+            q = qs[i]
+            if len(q.transcriptions.all()) != 1:
+                continue
+            t_one = str(q.transcriptions.all()[0]).encode('ascii')
+            o_one = [str(x) for x in q.orthographies.all()]
+            for j in range(i+1,len(qs)):
+                s = qs[j]
+                if len(s.transcriptions.all()) != 1:
+                    continue
+                t_two = str(s.transcriptions.all()[0]).encode('ascii')
+                o_two = [str(x) for x in s.orthographies.all()]
+                phon_dist = get_phone_dist(re.sub('\'','',t_one),re.sub('\'','',t_two))
+                #if not is_neighbour(re.sub('\'','',t_one),re.sub('\'','',t_two)):
+                #    if t_one != t_two:
+                #        continue
+                #    phon_dist = "homophone"
+                #else:
+                #    phon_dist = "neighbour"
+                in_context_entropy = in_trigram_context_entropy(o_one,o_two)
+                c_one = str(q.lemma.category.label).encode('ascii')
+                c_two = str(s.lemma.category.label).encode('ascii')
+                f_one = q.frequency
+                f_two = s.frequency
+                L_one = str(q.lemma.label).encode('ascii')
+                L_two = str(s.lemma.label).encode('ascii')
+                LFreq_one = q.lemma.frequency
+                LFreq_two = s.lemma.frequency
+                f.write('\t'.join([':'.join(o_one),':'.join(o_two),t_one,t_two,
+                                    c_one,c_two,f_one,f_two,L_one,L_two,
+                                    LFreq_one,LFreq_two,phon_dist,in_context_entropy]))
+                f.write("\n")
